# console-widgets

A Python package for displaying terminal based widgets.

![image](https://img.shields.io/github/languages/top/bornagojsic/console-widgets) ![image](https://img.shields.io/pypi/v/console-widgets) ![image](https://img.shields.io/pypi/l/console-widgets) 
<!--- ![image](https://img.shields.io/pypi/dd/console-widgets) --->

-   Github repo: <https://github.com/bornagojsic/console-widgets>
-   Free software: MIT license
-   Documentation: <https://console-widgets.readthedocs.io>.


Installation
------------

Download the package using pip:

    pip install console-widgets


Usage
-----

To use console-widgets in a project:

    import console_widgets
